@@ -7,7 +7,7 @@ use Scalar::Util 'looks_like_number';
 use List::Util   qw< min max uniq>;
 use version;
 
-our $VERSION = '0.000003';
+our $VERSION = '0.000004';
 
 # Default naming scheme for refactoring...
 my $DEFAULT_SUB_NAME          = '__REFACTORED_SUB__';
@@ -1753,6 +1753,13 @@ sub classify_all_vars_in {
                 (?<_save_var>
                     (?{
                         my ($var, $varid) = @{$^R};
+                        if (length($var) > 2) {
+                            while (1) {
+                                last if substr($var,1,1) ne '$';
+                                substr($var, 0, 1, q{});
+                                $varid++;
+                            }
+                        }
 
                         # Update the scope's information if this variable is being declared...
                         if ($Code::ART::varscope[-1]{allow_decls}) {
@@ -1958,7 +1965,7 @@ Code::ART - Analyze/Rename/Track Perl source code
 
 =head1 VERSION
 
-This document describes Code::ART version 0.000003
+This document describes Code::ART version 0.000004
 
 
 =head1 SYNOPSIS
@@ -2443,6 +2450,13 @@ Rename the variable under the cursor.
 
 Search for all instances of the variable under the cursor.
 
+B<I<WARNING>>: In some environments, C<CTRL-S> will suspend terminal
+interactions. If your terminal locks up when you use this mapping,
+hit C<CTRL-Q> to restart terminal interactions. In this case, 
+you will need to either change the behaviour of C<CTRL-S> in
+your terminal (for example: L<https://coderwall.com/p/ltiqsq/disable-ctrl-s-and-ctrl-q-on-terminal>),
+or else change this mapping to something else.>
+
 =item gd
 
 Jump to the declaration of the variable under the cursor.
